# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from killbill.api_client import ApiClient


class PaymentGatewayApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def build_combo_form_descriptor(self, body, x_killbill_created_by, **kwargs):  # noqa: E501
        """Combo API to generate form data to redirect the customer to the gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.build_combo_form_descriptor(body, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ComboHostedPaymentPage body: (required)
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param list[str] control_plugin_name:
        :param list[str] plugin_property:
        :return: HostedPaymentPageFormDescriptor
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.build_combo_form_descriptor_with_http_info(body, x_killbill_created_by, **kwargs)  # noqa: E501
        else:
            (data) = self.build_combo_form_descriptor_with_http_info(body, x_killbill_created_by, **kwargs)  # noqa: E501
            return data

    def build_combo_form_descriptor_with_http_info(self, body, x_killbill_created_by, **kwargs):  # noqa: E501
        """Combo API to generate form data to redirect the customer to the gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.build_combo_form_descriptor_with_http_info(body, x_killbill_created_by, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ComboHostedPaymentPage body: (required)
        :param str x_killbill_created_by: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param list[str] control_plugin_name:
        :param list[str] plugin_property:
        :return: HostedPaymentPageFormDescriptor
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'x_killbill_reason', 'x_killbill_comment', 'control_plugin_name', 'plugin_property']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method build_combo_form_descriptor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `build_combo_form_descriptor`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `build_combo_form_descriptor`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'control_plugin_name' in params:
            query_params.append(('controlPluginName', params['control_plugin_name']))  # noqa: E501
            collection_formats['controlPluginName'] = 'multi'  # noqa: E501
        if 'plugin_property' in params:
            query_params.append(('pluginProperty', params['plugin_property']))  # noqa: E501
            collection_formats['pluginProperty'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/paymentGateways/hosted/form', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='HostedPaymentPageFormDescriptor',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def build_form_descriptor(self, body, x_killbill_created_by, account_id, **kwargs):  # noqa: E501
        """Generate form data to redirect the customer to the gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.build_form_descriptor(body, x_killbill_created_by, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param HostedPaymentPageFields body: (required)
        :param str x_killbill_created_by: (required)
        :param str account_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param str payment_method_id:
        :param list[str] control_plugin_name:
        :param list[str] plugin_property:
        :return: HostedPaymentPageFormDescriptor
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.build_form_descriptor_with_http_info(body, x_killbill_created_by, account_id, **kwargs)  # noqa: E501
        else:
            (data) = self.build_form_descriptor_with_http_info(body, x_killbill_created_by, account_id, **kwargs)  # noqa: E501
            return data

    def build_form_descriptor_with_http_info(self, body, x_killbill_created_by, account_id, **kwargs):  # noqa: E501
        """Generate form data to redirect the customer to the gateway  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.build_form_descriptor_with_http_info(body, x_killbill_created_by, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param HostedPaymentPageFields body: (required)
        :param str x_killbill_created_by: (required)
        :param str account_id: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param str payment_method_id:
        :param list[str] control_plugin_name:
        :param list[str] plugin_property:
        :return: HostedPaymentPageFormDescriptor
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'account_id', 'x_killbill_reason', 'x_killbill_comment', 'payment_method_id', 'control_plugin_name', 'plugin_property']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method build_form_descriptor" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `build_form_descriptor`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `build_form_descriptor`")  # noqa: E501
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params or
                params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `build_form_descriptor`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']  # noqa: E501

        query_params = []
        if 'payment_method_id' in params:
            query_params.append(('paymentMethodId', params['payment_method_id']))  # noqa: E501
        if 'control_plugin_name' in params:
            query_params.append(('controlPluginName', params['control_plugin_name']))  # noqa: E501
            collection_formats['controlPluginName'] = 'multi'  # noqa: E501
        if 'plugin_property' in params:
            query_params.append(('pluginProperty', params['plugin_property']))  # noqa: E501
            collection_formats['pluginProperty'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/paymentGateways/hosted/form/{accountId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='HostedPaymentPageFormDescriptor',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_notification(self, body, x_killbill_created_by, plugin_name, **kwargs):  # noqa: E501
        """Process a gateway notification  # noqa: E501

        The response is built by the appropriate plugin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_notification(body, x_killbill_created_by, plugin_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: (required)
        :param str x_killbill_created_by: (required)
        :param str plugin_name: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param list[str] control_plugin_name:
        :param list[str] plugin_property:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.process_notification_with_http_info(body, x_killbill_created_by, plugin_name, **kwargs)  # noqa: E501
        else:
            (data) = self.process_notification_with_http_info(body, x_killbill_created_by, plugin_name, **kwargs)  # noqa: E501
            return data

    def process_notification_with_http_info(self, body, x_killbill_created_by, plugin_name, **kwargs):  # noqa: E501
        """Process a gateway notification  # noqa: E501

        The response is built by the appropriate plugin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_notification_with_http_info(body, x_killbill_created_by, plugin_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str body: (required)
        :param str x_killbill_created_by: (required)
        :param str plugin_name: (required)
        :param str x_killbill_reason:
        :param str x_killbill_comment:
        :param list[str] control_plugin_name:
        :param list[str] plugin_property:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_killbill_created_by', 'plugin_name', 'x_killbill_reason', 'x_killbill_comment', 'control_plugin_name', 'plugin_property']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_notification" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `process_notification`")  # noqa: E501
        # verify the required parameter 'x_killbill_created_by' is set
        if ('x_killbill_created_by' not in params or
                params['x_killbill_created_by'] is None):
            raise ValueError("Missing the required parameter `x_killbill_created_by` when calling `process_notification`")  # noqa: E501
        # verify the required parameter 'plugin_name' is set
        if ('plugin_name' not in params or
                params['plugin_name'] is None):
            raise ValueError("Missing the required parameter `plugin_name` when calling `process_notification`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'plugin_name' in params:
            path_params['pluginName'] = params['plugin_name']  # noqa: E501

        query_params = []
        if 'control_plugin_name' in params:
            query_params.append(('controlPluginName', params['control_plugin_name']))  # noqa: E501
            collection_formats['controlPluginName'] = 'multi'  # noqa: E501
        if 'plugin_property' in params:
            query_params.append(('pluginProperty', params['plugin_property']))  # noqa: E501
            collection_formats['pluginProperty'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_killbill_created_by' in params:
            header_params['X-Killbill-CreatedBy'] = params['x_killbill_created_by']  # noqa: E501
        if 'x_killbill_reason' in params:
            header_params['X-Killbill-Reason'] = params['x_killbill_reason']  # noqa: E501
        if 'x_killbill_comment' in params:
            header_params['X-Killbill-Comment'] = params['x_killbill_comment']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Killbill Api Key', 'Killbill Api Secret', 'basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/1.0/kb/paymentGateways/notification/{pluginName}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.tag_definition_api import TagDefinitionApi  # noqa: E501
from killbill.rest import ApiException


class TestTagDefinitionApi(unittest.TestCase):
    """TagDefinitionApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.tag_definition_api.TagDefinitionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tag_definition(self):
        """Test case for create_tag_definition

        Create a tag definition  # noqa: E501
        """
        pass

    def test_delete_tag_definition(self):
        """Test case for delete_tag_definition

        Delete a tag definition  # noqa: E501
        """
        pass

    def test_get_tag_definition(self):
        """Test case for get_tag_definition

        Retrieve a tag definition  # noqa: E501
        """
        pass

    def test_get_tag_definition_audit_logs_with_history(self):
        """Test case for get_tag_definition_audit_logs_with_history

        Retrieve tag definition audit logs with history by id  # noqa: E501
        """
        pass

    def test_get_tag_definitions(self):
        """Test case for get_tag_definitions

        List tag definitions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Tag(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tag_id': 'str',
        'object_type': 'str',
        'object_id': 'str',
        'tag_definition_id': 'str',
        'tag_definition_name': 'str',
        'audit_logs': 'list[AuditLog]'
    }

    attribute_map = {
        'tag_id': 'tagId',
        'object_type': 'objectType',
        'object_id': 'objectId',
        'tag_definition_id': 'tagDefinitionId',
        'tag_definition_name': 'tagDefinitionName',
        'audit_logs': 'auditLogs'
    }

    def __init__(self, tag_id=None, object_type=None, object_id=None, tag_definition_id=None, tag_definition_name=None, audit_logs=None):  # noqa: E501
        """Tag - a model defined in Swagger"""  # noqa: E501
        self._tag_id = None
        self._object_type = None
        self._object_id = None
        self._tag_definition_id = None
        self._tag_definition_name = None
        self._audit_logs = None
        self.discriminator = None
        if tag_id is not None:
            self.tag_id = tag_id
        if object_type is not None:
            self.object_type = object_type
        if object_id is not None:
            self.object_id = object_id
        if tag_definition_id is not None:
            self.tag_definition_id = tag_definition_id
        if tag_definition_name is not None:
            self.tag_definition_name = tag_definition_name
        if audit_logs is not None:
            self.audit_logs = audit_logs

    @property
    def tag_id(self):
        """Gets the tag_id of this Tag.  # noqa: E501


        :return: The tag_id of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._tag_id

    @tag_id.setter
    def tag_id(self, tag_id):
        """Sets the tag_id of this Tag.


        :param tag_id: The tag_id of this Tag.  # noqa: E501
        :type: str
        """

        self._tag_id = tag_id

    @property
    def object_type(self):
        """Gets the object_type of this Tag.  # noqa: E501


        :return: The object_type of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this Tag.


        :param object_type: The object_type of this Tag.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACCOUNT", "ACCOUNT_EMAIL", "BLOCKING_STATES", "BUNDLE", "CUSTOM_FIELD", "INVOICE", "PAYMENT", "TRANSACTION", "INVOICE_ITEM", "INVOICE_PAYMENT", "SUBSCRIPTION", "SUBSCRIPTION_EVENT", "SERVICE_BROADCAST", "PAYMENT_ATTEMPT", "PAYMENT_METHOD", "TAG", "TAG_DEFINITION", "TENANT", "TENANT_KVS"]  # noqa: E501
        if object_type not in allowed_values:
            raise ValueError(
                "Invalid value for `object_type` ({0}), must be one of {1}"  # noqa: E501
                .format(object_type, allowed_values)
            )

        self._object_type = object_type

    @property
    def object_id(self):
        """Gets the object_id of this Tag.  # noqa: E501


        :return: The object_id of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this Tag.


        :param object_id: The object_id of this Tag.  # noqa: E501
        :type: str
        """

        self._object_id = object_id

    @property
    def tag_definition_id(self):
        """Gets the tag_definition_id of this Tag.  # noqa: E501


        :return: The tag_definition_id of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._tag_definition_id

    @tag_definition_id.setter
    def tag_definition_id(self, tag_definition_id):
        """Sets the tag_definition_id of this Tag.


        :param tag_definition_id: The tag_definition_id of this Tag.  # noqa: E501
        :type: str
        """

        self._tag_definition_id = tag_definition_id

    @property
    def tag_definition_name(self):
        """Gets the tag_definition_name of this Tag.  # noqa: E501


        :return: The tag_definition_name of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._tag_definition_name

    @tag_definition_name.setter
    def tag_definition_name(self, tag_definition_name):
        """Sets the tag_definition_name of this Tag.


        :param tag_definition_name: The tag_definition_name of this Tag.  # noqa: E501
        :type: str
        """

        self._tag_definition_name = tag_definition_name

    @property
    def audit_logs(self):
        """Gets the audit_logs of this Tag.  # noqa: E501


        :return: The audit_logs of this Tag.  # noqa: E501
        :rtype: list[AuditLog]
        """
        return self._audit_logs

    @audit_logs.setter
    def audit_logs(self, audit_logs):
        """Sets the audit_logs of this Tag.


        :param audit_logs: The audit_logs of this Tag.  # noqa: E501
        :type: list[AuditLog]
        """

        self._audit_logs = audit_logs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Tag, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tag):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SubscriptionUsageRecord(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'subscription_id': 'str',
        'tracking_id': 'str',
        'unit_usage_records': 'list[UnitUsageRecord]'
    }

    attribute_map = {
        'subscription_id': 'subscriptionId',
        'tracking_id': 'trackingId',
        'unit_usage_records': 'unitUsageRecords'
    }

    def __init__(self, subscription_id=None, tracking_id=None, unit_usage_records=None):  # noqa: E501
        """SubscriptionUsageRecord - a model defined in Swagger"""  # noqa: E501
        self._subscription_id = None
        self._tracking_id = None
        self._unit_usage_records = None
        self.discriminator = None
        self.subscription_id = subscription_id
        if tracking_id is not None:
            self.tracking_id = tracking_id
        self.unit_usage_records = unit_usage_records

    @property
    def subscription_id(self):
        """Gets the subscription_id of this SubscriptionUsageRecord.  # noqa: E501


        :return: The subscription_id of this SubscriptionUsageRecord.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this SubscriptionUsageRecord.


        :param subscription_id: The subscription_id of this SubscriptionUsageRecord.  # noqa: E501
        :type: str
        """
        if subscription_id is None:
            raise ValueError("Invalid value for `subscription_id`, must not be `None`")  # noqa: E501

        self._subscription_id = subscription_id

    @property
    def tracking_id(self):
        """Gets the tracking_id of this SubscriptionUsageRecord.  # noqa: E501


        :return: The tracking_id of this SubscriptionUsageRecord.  # noqa: E501
        :rtype: str
        """
        return self._tracking_id

    @tracking_id.setter
    def tracking_id(self, tracking_id):
        """Sets the tracking_id of this SubscriptionUsageRecord.


        :param tracking_id: The tracking_id of this SubscriptionUsageRecord.  # noqa: E501
        :type: str
        """

        self._tracking_id = tracking_id

    @property
    def unit_usage_records(self):
        """Gets the unit_usage_records of this SubscriptionUsageRecord.  # noqa: E501


        :return: The unit_usage_records of this SubscriptionUsageRecord.  # noqa: E501
        :rtype: list[UnitUsageRecord]
        """
        return self._unit_usage_records

    @unit_usage_records.setter
    def unit_usage_records(self, unit_usage_records):
        """Sets the unit_usage_records of this SubscriptionUsageRecord.


        :param unit_usage_records: The unit_usage_records of this SubscriptionUsageRecord.  # noqa: E501
        :type: list[UnitUsageRecord]
        """
        if unit_usage_records is None:
            raise ValueError("Invalid value for `unit_usage_records`, must not be `None`")  # noqa: E501

        self._unit_usage_records = unit_usage_records

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SubscriptionUsageRecord, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionUsageRecord):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kill Bill

    Kill Bill is an open-source billing and payments platform  # noqa: E501

    OpenAPI spec version: 0.22.22-SNAPSHOT
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import killbill
from killbill.api.admin_api import AdminApi  # noqa: E501
from killbill.rest import ApiException


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self):
        self.api = killbill.api.admin_api.AdminApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_queue_entries(self):
        """Test case for get_queue_entries

        Get queues entries  # noqa: E501
        """
        pass

    def test_invalidates_cache(self):
        """Test case for invalidates_cache

        Invalidates the given Cache if specified, otherwise invalidates all caches  # noqa: E501
        """
        pass

    def test_invalidates_cache_by_account(self):
        """Test case for invalidates_cache_by_account

        Invalidates Caches per account level  # noqa: E501
        """
        pass

    def test_invalidates_cache_by_tenant(self):
        """Test case for invalidates_cache_by_tenant

        Invalidates Caches per tenant level  # noqa: E501
        """
        pass

    def test_put_in_rotation(self):
        """Test case for put_in_rotation

        Put the host back into rotation  # noqa: E501
        """
        pass

    def test_put_out_of_rotation(self):
        """Test case for put_out_of_rotation

        Put the host out of rotation  # noqa: E501
        """
        pass

    def test_trigger_invoice_generation_for_parked_accounts(self):
        """Test case for trigger_invoice_generation_for_parked_accounts

        Trigger an invoice generation for all parked accounts  # noqa: E501
        """
        pass

    def test_update_payment_transaction_state(self):
        """Test case for update_payment_transaction_state

        Update existing paymentTransaction and associated payment state  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
